## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""
Tests for payment containers.
"""
import unittest
import tempfile
import shutil
from zope.interface.verify import verifyClass, verifyObject
from zope.component.interfaces import IFactory
from zope.component.hooks import setSite, clearSite
from waeup.sirp.app import University
from waeup.sirp.payments.interfaces import (
    IPaymentsContainer,
    )
from waeup.sirp.payments.container import (
    PaymentsContainer,
    )
from waeup.sirp.testing import (
    FunctionalLayer, FunctionalTestCase, get_all_loggers, remove_new_loggers,
    remove_logger)

class PaymentsContainerTestCase(FunctionalTestCase):

    layer = FunctionalLayer

    def setUp(self):
        remove_logger('waeup.sirp.app.students')
        super(PaymentsContainerTestCase, self).setUp()
        # Setup a sample site for each test
        # Prepopulate the ZODB...
        app = University()
        self.getRootFolder()['app'] = app
        self.app = self.getRootFolder()['app']
        setSite(self.app)
        self.dc_root = tempfile.mkdtemp()
        app['datacenter'].setStoragePath(self.dc_root)
        return

    def tearDown(self):
        super(PaymentsContainerTestCase, self).tearDown()
        clearSite()
        shutil.rmtree(self.dc_root)
        return

    def test_interfaces(self):
        # Make sure the correct interfaces are implemented.
        self.assertTrue(
            verifyClass(
                IPaymentsContainer, PaymentsContainer)
            )
        self.assertTrue(
            verifyObject(
                IPaymentsContainer, PaymentsContainer())
            )
        return

    def test_base(self):
        # We cannot call the fundamental methods of a base in that case
        container = PaymentsContainer()
        self.assertRaises(
            NotImplementedError, container.archive)
        self.assertRaises(
            NotImplementedError, container.clear)
